window.Gleam.initSearch([{"doc":"mist","title":"mist","content":"# mist\n\nA (hopefully) nice, pure Gleam web server\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add mist\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/mist&gt;.\n\n## Usage\n\nRight now there are a few options.  Let&#39;s say you want a &quot;simple&quot; HTTP server\nthat you can customize to your heart&#39;s content.  In that case, you want:\n\n```gleam\nimport mist\nimport gleam/bit_builder\nimport gleam/erlang/process\nimport gleam/http/response\n\npub fn main() {\n  assert Ok(_) =\n    mist.run_service(\n      8080,\n      fn(_req) {\n        response.new(200)\n        |&gt; response.set_body(bit_builder.from_bit_string(&lt;&lt;\n          &quot;hello, world!&quot;:utf8,\n        &gt;&gt;))\n      },\n      max_body_limit: 4_000_000\n    )\n  process.sleep_forever()\n}\n```\n\nMaybe you also want to work with websockets.  Maybe those should only be\nupgradable at a certain endpoint.  For that, you can use `handler.with_func`.\nThe websocket methods help you build a handler with connect/disconnect handlers.\nYou can use these to, for example, track connected clients.  For example:\n\n```gleam\nimport mist\nimport gleam/bit_builder\nimport gleam/erlang/process\nimport gleam/http.{Get, Post}\nimport gleam/http/request\nimport gleam/http/response\nimport gleam/result\nimport mist/handler.{Response, Upgrade}\nimport mist/http.{BitBuilderBody}\nimport mist/websocket\n\npub fn main() {\n  assert Ok(_) =\n    mist.serve(\n      8080,\n      handler.with_func(fn(req) {\n        case req.method, request.path_segments(req) {\n          Get, [&quot;echo&quot;, &quot;test&quot;] -&gt;\n            websocket.echo_handler\n            |&gt; websocket.with_handler\n            |&gt; Upgrade\n          Post, [&quot;echo&quot;, &quot;body&quot;] -&gt;\n            req\n            |&gt; http.read_body\n            |&gt; result.map(fn(req) {\n              response.new(200)\n              |&gt; response.set_body(BitBuilderBody(bit_builder.from_bit_string(\n                req.body,\n              )))\n              |&gt; response.prepend_header(\n                &quot;content-type&quot;,\n                request.get_header(req, &quot;content-type&quot;)\n                |&gt; result.unwrap(&quot;application/octet-stream&quot;),\n              )\n            })\n            |&gt; result.unwrap(\n              response.new(400)\n              |&gt; response.set_body(BitBuilderBody(bit_builder.new())),\n            )\n            |&gt; Response\n          Get, [&quot;home&quot;] -&gt;\n            response.new(200)\n            |&gt; response.set_body(BitBuilderBody(bit_builder.from_bit_string(&lt;&lt;\n              &quot;sup home boy&quot;:utf8,\n            &gt;&gt;)))\n            |&gt; Response\n          _, _ -&gt;\n            response.new(200)\n            |&gt; response.set_body(BitBuilderBody(bit_builder.from_bit_string(&lt;&lt;\n              &quot;Hello, world!&quot;:utf8,\n            &gt;&gt;)))\n            |&gt; Response\n        }\n      }),\n    )\n  process.sleep_forever()\n}\n```\n\nYou might also want to use SSL.  You can do that with the following options.\n\nWith `run_service_ssl`:\n\n```gleam\nimport mist\nimport gleam/bit_builder\nimport gleam/erlang/process\nimport gleam/http/response\n\npub fn main() {\n  assert Ok(_) =\n    mist.run_service_ssl(\n      port: 8080,\n      certfile: &quot;/path/to/server.crt&quot;,\n      keyfile: &quot;/path/to/server.key&quot;,\n      handler: fn(_req) {\n        response.new(200)\n        |&gt; response.set_body(bit_builder.from_bit_string(&lt;&lt;\n          &quot;hello, world!&quot;:utf8,\n        &gt;&gt;))\n      },\n      max_body_limit: 4_000_000\n    )\n  process.sleep_forever()\n}\n```\n\nWith `serve_ssl`:\n\n```gleam\npub fn main() {\n  assert Ok(_) =\n    mist.serve_ssl(\n      port: 8080,\n      certfile: &quot;...&quot;,\n      keyfile: &quot;...&quot;,\n      handler.with_func(fn(req) {\n        todo\n      }\n    )\n  // ...\n}\n```\n\nThere is support for sending files as well. This uses the `file:sendfile` erlang\nmethod under the hood.\n\n```gleam\nimport gleam/bit_builder\nimport gleam/bit_string\nimport gleam/erlang/process\nimport gleam/http/request.{Request}\nimport gleam/http/response\nimport gleam/int\nimport gleam/string\nimport mist\nimport mist/file\nimport mist/handler.{Response}\nimport mist/http.{BitBuilderBody, Body, FileBody}\n\npub fn main() {\n  assert Ok(_) =\n    mist.serve(\n      8080,\n      handler.with_func(fn(req: Request(Body)) {\n        case request.path_segments(req) {\n          [&quot;static&quot;, ..path] -&gt; {\n            // verify, validate, etc\n            let file_path =\n              path\n              |&gt; string.join(&quot;/&quot;)\n              |&gt; string.append(&quot;/&quot;, _)\n              |&gt; bit_string.from_string\n            let size = file.size(file_path)\n            assert Ok(fd) = file.open(file_path)\n            response.new(200)\n            |&gt; response.set_body(FileBody(fd, int.to_string(size), 0, size))\n            |&gt; Response\n          }\n          _ -&gt;\n            response.new(404)\n            |&gt; response.set_body(BitBuilderBody(bit_builder.new()))\n            |&gt; Response\n        }\n      }),\n    )\n  process.sleep_forever()\n}\n```\n\nYou can return chunked responses using the `mist/http.{Chunked}` response body\ntype. This takes an `Iterator(BitBuilder)` and handles sending the initial\nresponse, and subsequent chunks in the proper format as they are emitted from\nthe iterator.\n\nIf you need something a little more complex or custom, you can always use the\nhelpers exported by the various `glisten`/`mist` modules.\n\n## Benchmarks\n\nThese are currently located [here](https://github.com/rawhat/http-benchmarks)\n","url":"index.html"},{"doc":"mist/websocket","title":"Frame","content":"pub type Frame {\n  CloseFrame(payload_length: Int, payload: BitString)\n  TextFrame(payload_length: Int, payload: BitString)\n  BinaryFrame(payload_length: Int, payload: BitString)\n  PingFrame(payload_length: Int, payload: BitString)\n  PongFrame(payload_length: Int, payload: BitString)\n}\n\nCloseFrame(payload_length: Int, payload: BitString)\n\n\nTextFrame(payload_length: Int, payload: BitString)\n\n\nBinaryFrame(payload_length: Int, payload: BitString)\n\n\nPingFrame(payload_length: Int, payload: BitString)\n\n\nPongFrame(payload_length: Int, payload: BitString)\n\n\nSynonyms:\nmist/websocket.Frame\nmist/websocket Frame","url":"mist/websocket.html#Frame"},{"doc":"mist/websocket","title":"Handler","content":"pub type Handler =\n  fn(Message, Subject(HandlerMessage)) -&gt; Result(Nil, Nil)\n\n\nSynonyms:\nmist/websocket.Handler\nmist/websocket Handler","url":"mist/websocket.html#Handler"},{"doc":"mist/websocket","title":"Message","content":"pub type Message {\n  BinaryMessage(data: BitString)\n  TextMessage(data: String)\n}\n\nBinaryMessage(data: BitString)\n\n\nTextMessage(data: String)\n\n\nSynonyms:\nmist/websocket.Message\nmist/websocket Message","url":"mist/websocket.html#Message"},{"doc":"mist/websocket","title":"ShaHash","content":"pub type ShaHash {\n  Sha\n}\n\nSha\n\n\nSynonyms:\nmist/websocket.ShaHash\nmist/websocket ShaHash","url":"mist/websocket.html#ShaHash"},{"doc":"mist/websocket","title":"WebsocketHandler","content":"pub type WebsocketHandler {\n  WebsocketHandler(\n    on_close: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n    on_init: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n    handler: Handler,\n  )\n}\n\nWebsocketHandler(\n  on_close: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n  on_init: Option(fn(Subject(HandlerMessage)) -&gt; Nil),\n  handler: Handler,\n)\n\n\nSynonyms:\nmist/websocket.WebsocketHandler\nmist/websocket WebsocketHandler","url":"mist/websocket.html#WebsocketHandler"},{"doc":"mist/websocket","title":"base64_encode","content":"pub external fn base64_encode(data: String) -&gt; String\n\nSynonyms:\nmist/websocket.base64_encode\nmist/websocket base64_encode","url":"mist/websocket.html#base64_encode"},{"doc":"mist/websocket","title":"crypto_hash","content":"pub external fn crypto_hash(\n  hash: ShaHash,\n  data: String,\n) -&gt; String\n\nSynonyms:\nmist/websocket.crypto_hash\nmist/websocket crypto_hash","url":"mist/websocket.html#crypto_hash"},{"doc":"mist/websocket","title":"echo_handler","content":"pub fn echo_handler(message: Message, sender: Subject(\n    HandlerMessage,\n  )) -&gt; Result(Nil, Nil)\n\nSynonyms:\nmist/websocket.echo_handler\nmist/websocket echo_handler","url":"mist/websocket.html#echo_handler"},{"doc":"mist/websocket","title":"frame_from_message","content":"pub fn frame_from_message(socket: Socket, transport: Transport, message: BitString) -&gt; Result(\n  Frame,\n  Nil,\n)\n\nSynonyms:\nmist/websocket.frame_from_message\nmist/websocket frame_from_message","url":"mist/websocket.html#frame_from_message"},{"doc":"mist/websocket","title":"frame_to_bit_builder","content":"pub fn frame_to_bit_builder(frame: Frame) -&gt; BitBuilder\n\nSynonyms:\nmist/websocket.frame_to_bit_builder\nmist/websocket frame_to_bit_builder","url":"mist/websocket.html#frame_to_bit_builder"},{"doc":"mist/websocket","title":"on_close","content":"pub fn on_close(handler: WebsocketHandler, func: fn(\n    Subject(HandlerMessage),\n  ) -&gt; Nil) -&gt; WebsocketHandler\n\nSynonyms:\nmist/websocket.on_close\nmist/websocket on_close","url":"mist/websocket.html#on_close"},{"doc":"mist/websocket","title":"on_init","content":"pub fn on_init(handler: WebsocketHandler, func: fn(\n    Subject(HandlerMessage),\n  ) -&gt; Nil) -&gt; WebsocketHandler\n\nSynonyms:\nmist/websocket.on_init\nmist/websocket on_init","url":"mist/websocket.html#on_init"},{"doc":"mist/websocket","title":"parse_key","content":"pub fn parse_key(key: String) -&gt; String\n\nSynonyms:\nmist/websocket.parse_key\nmist/websocket parse_key","url":"mist/websocket.html#parse_key"},{"doc":"mist/websocket","title":"send","content":"pub fn send(sender: Subject(HandlerMessage), message: Message) -&gt; Nil\n Helper to encapsulate the logic to send a provided message over the\n WebSocket\nSynonyms:\nmist/websocket.send\nmist/websocket send","url":"mist/websocket.html#send"},{"doc":"mist/websocket","title":"with_handler","content":"pub fn with_handler(func: fn(Message, Subject(HandlerMessage)) -&gt;\n    Result(Nil, Nil)) -&gt; WebsocketHandler\n\nSynonyms:\nmist/websocket.with_handler\nmist/websocket with_handler","url":"mist/websocket.html#with_handler"},{"doc":"mist/websocket","title":"mist/websocket","content":"","url":"mist/websocket.html"},{"doc":"mist/encoder","title":"encode_headers","content":"pub fn encode_headers(headers: List(#(String, String))) -&gt; BitBuilder\n\nSynonyms:\nmist/encoder.encode_headers\nmist/encoder encode_headers","url":"mist/encoder.html#encode_headers"},{"doc":"mist/encoder","title":"response_builder","content":"pub fn response_builder(status: Int, headers: List(\n    #(String, String),\n  )) -&gt; BitBuilder\n\nSynonyms:\nmist/encoder.response_builder\nmist/encoder response_builder","url":"mist/encoder.html#response_builder"},{"doc":"mist/encoder","title":"status_to_bit_string","content":"pub fn status_to_bit_string(status: Int) -&gt; BitString\n\nSynonyms:\nmist/encoder.status_to_bit_string\nmist/encoder status_to_bit_string","url":"mist/encoder.html#status_to_bit_string"},{"doc":"mist/encoder","title":"to_bit_builder","content":"pub fn to_bit_builder(resp: Response(BitBuilder)) -&gt; BitBuilder\n Turns an HTTP response into a TCP message\nSynonyms:\nmist/encoder.to_bit_builder\nmist/encoder to_bit_builder","url":"mist/encoder.html#to_bit_builder"},{"doc":"mist/encoder","title":"mist/encoder","content":"","url":"mist/encoder.html"},{"doc":"mist/file","title":"FileDescriptor","content":"pub external type FileDescriptor\n\n\nSynonyms:\nmist/file.FileDescriptor\nmist/file FileDescriptor","url":"mist/file.html#FileDescriptor"},{"doc":"mist/file","title":"FileMode","content":"pub type FileMode {\n  Raw\n}\n\nRaw\n\n\nSynonyms:\nmist/file.FileMode\nmist/file FileMode","url":"mist/file.html#FileMode"},{"doc":"mist/file","title":"open","content":"pub fn open(file: BitString) -&gt; Result(FileDescriptor, Atom)\n\nSynonyms:\nmist/file.open\nmist/file open","url":"mist/file.html#open"},{"doc":"mist/file","title":"sendfile","content":"pub external fn sendfile(\n  file_descriptor: FileDescriptor,\n  socket: Socket,\n  offset: Int,\n  bytes: Int,\n  options: List(a),\n) -&gt; Result(Int, Atom)\n\nSynonyms:\nmist/file.sendfile\nmist/file sendfile","url":"mist/file.html#sendfile"},{"doc":"mist/file","title":"size","content":"pub external fn size(path: BitString) -&gt; Int\n\nSynonyms:\nmist/file.size\nmist/file size","url":"mist/file.html#size"},{"doc":"mist/file","title":"uri_unquote","content":"pub external fn uri_unquote(uri: String) -&gt; String\n\nSynonyms:\nmist/file.uri_unquote\nmist/file uri_unquote","url":"mist/file.html#uri_unquote"},{"doc":"mist/file","title":"mist/file","content":"","url":"mist/file.html"},{"doc":"mist/http","title":"Body","content":"pub opaque type Body\n\n\nSynonyms:\nmist/http.Body\nmist/http Body","url":"mist/http.html#Body"},{"doc":"mist/http","title":"Buffer","content":"pub type Buffer {\n  Buffer(remaining: Int, data: BitString)\n}\n\nBuffer(remaining: Int, data: BitString)\n\n\nSynonyms:\nmist/http.Buffer\nmist/http Buffer","url":"mist/http.html#Buffer"},{"doc":"mist/http","title":"DecodeError","content":"pub type DecodeError {\n  MalformedRequest\n  InvalidMethod\n  InvalidPath\n  UnknownHeader\n  UnknownMethod\n  InvalidBody\n  DiscardPacket\n}\n\nMalformedRequest\n\n\nInvalidMethod\n\n\nInvalidPath\n\n\nUnknownHeader\n\n\nUnknownMethod\n\n\nInvalidBody\n\n\nDiscardPacket\n\n\nSynonyms:\nmist/http.DecodeError\nmist/http DecodeError","url":"mist/http.html#DecodeError"},{"doc":"mist/http","title":"DecodedPacket","content":"pub type DecodedPacket {\n  BinaryData(HttpPacket, BitString)\n  EndOfHeaders(BitString)\n  MoreData(Option(Int))\n}\n\nBinaryData(HttpPacket, BitString)\n\n\nEndOfHeaders(BitString)\n\n\nMoreData(Option(Int))\n\n\nSynonyms:\nmist/http.DecodedPacket\nmist/http DecodedPacket","url":"mist/http.html#DecodedPacket"},{"doc":"mist/http","title":"HttpPacket","content":"pub type HttpPacket {\n  HttpRequest(Dynamic, HttpUri, #(Int, Int))\n  HttpHeader(Int, Atom, BitString, BitString)\n}\n\nHttpRequest(Dynamic, HttpUri, #(Int, Int))\n\n\nHttpHeader(Int, Atom, BitString, BitString)\n\n\nSynonyms:\nmist/http.HttpPacket\nmist/http HttpPacket","url":"mist/http.html#HttpPacket"},{"doc":"mist/http","title":"HttpResponseBody","content":"pub type HttpResponseBody {\n  BitBuilderBody(BitBuilder)\n  Chunked(Iterator(BitBuilder))\n  FileBody(\n    file_descriptor: file.FileDescriptor,\n    content_type: String,\n    offset: Int,\n    length: Int,\n  )\n}\n\nBitBuilderBody(BitBuilder)\n\n\nChunked(Iterator(BitBuilder))\n\n\nFileBody(\n  file_descriptor: file.FileDescriptor,\n  content_type: String,\n  offset: Int,\n  length: Int,\n)\n\n\nSynonyms:\nmist/http.HttpResponseBody\nmist/http HttpResponseBody","url":"mist/http.html#HttpResponseBody"},{"doc":"mist/http","title":"HttpUri","content":"pub type HttpUri {\n  AbsPath(BitString)\n}\n\nAbsPath(BitString)\n\n\nSynonyms:\nmist/http.HttpUri\nmist/http HttpUri","url":"mist/http.html#HttpUri"},{"doc":"mist/http","title":"PacketType","content":"pub type PacketType {\n  Http\n  HttphBin\n  HttpBin\n}\n\nHttp\n\n\nHttphBin\n\n\nHttpBin\n\n\nSynonyms:\nmist/http.PacketType\nmist/http PacketType","url":"mist/http.html#PacketType"},{"doc":"mist/http","title":"add_default_headers","content":"pub fn add_default_headers(resp: Response(BitBuilder)) -&gt; Response(\n  BitBuilder,\n)\n\nSynonyms:\nmist/http.add_default_headers\nmist/http add_default_headers","url":"mist/http.html#add_default_headers"},{"doc":"mist/http","title":"from_header","content":"pub fn from_header(value: BitString) -&gt; String\n\nSynonyms:\nmist/http.from_header\nmist/http from_header","url":"mist/http.html#from_header"},{"doc":"mist/http","title":"parse_headers","content":"pub fn parse_headers(bs: BitString, socket: Socket, transport: Transport, headers: Map(\n    String,\n    String,\n  )) -&gt; Result(#(Map(String, String), BitString), DecodeError)\n\nSynonyms:\nmist/http.parse_headers\nmist/http parse_headers","url":"mist/http.html#parse_headers"},{"doc":"mist/http","title":"parse_request","content":"pub fn parse_request(bs: BitString, socket: Socket, transport: Transport) -&gt; Result(\n  Request(Body),\n  DecodeError,\n)\n Turns the TCP message into an HTTP request\nSynonyms:\nmist/http.parse_request\nmist/http parse_request","url":"mist/http.html#parse_request"},{"doc":"mist/http","title":"read_body","content":"pub fn read_body(req: Request(Body)) -&gt; Result(\n  Request(BitString),\n  DecodeError,\n)\n\nSynonyms:\nmist/http.read_body\nmist/http read_body","url":"mist/http.html#read_body"},{"doc":"mist/http","title":"read_data","content":"pub fn read_data(socket: Socket, transport: Transport, buffer: Buffer, error: DecodeError) -&gt; Result(\n  BitString,\n  DecodeError,\n)\n\nSynonyms:\nmist/http.read_data\nmist/http read_data","url":"mist/http.html#read_data"},{"doc":"mist/http","title":"upgrade","content":"pub fn upgrade(socket: Socket, transport: Transport, req: Request(\n    Body,\n  )) -&gt; Result(Nil, Nil)\n\nSynonyms:\nmist/http.upgrade\nmist/http upgrade","url":"mist/http.html#upgrade"},{"doc":"mist/http","title":"upgrade_socket","content":"pub fn upgrade_socket(req: Request(Body)) -&gt; Result(\n  Response(BitBuilder),\n  Request(Body),\n)\n\nSynonyms:\nmist/http.upgrade_socket\nmist/http upgrade_socket","url":"mist/http.html#upgrade_socket"},{"doc":"mist/http","title":"mist/http","content":"","url":"mist/http.html"},{"doc":"mist/logger","title":"error","content":"pub fn error(data: a) -&gt; Nil\n\nSynonyms:\nmist/logger.error\nmist/logger error","url":"mist/logger.html#error"},{"doc":"mist/logger","title":"mist/logger","content":"","url":"mist/logger.html"},{"doc":"mist/handler","title":"Handler","content":"pub type Handler =\n  fn(request.Request(BitString)) -&gt; response.Response(BitBuilder)\n\n\nSynonyms:\nmist/handler.Handler\nmist/handler Handler","url":"mist/handler.html#Handler"},{"doc":"mist/handler","title":"HandlerError","content":"pub type HandlerError {\n  InvalidRequest(DecodeError)\n  NotFound\n}\n\nInvalidRequest(DecodeError)\n\n\nNotFound\n\n\nSynonyms:\nmist/handler.HandlerError\nmist/handler HandlerError","url":"mist/handler.html#HandlerError"},{"doc":"mist/handler","title":"HandlerFunc","content":"pub type HandlerFunc =\n  fn(Request(Body)) -&gt; HandlerResponse\n\n\nSynonyms:\nmist/handler.HandlerFunc\nmist/handler HandlerFunc","url":"mist/handler.html#HandlerFunc"},{"doc":"mist/handler","title":"HandlerResponse","content":"pub type HandlerResponse {\n  Response(response: response.Response(HttpResponseBody))\n  Upgrade(websocket.WebsocketHandler)\n}\n\nResponse(response: response.Response(HttpResponseBody))\n\n\nUpgrade(websocket.WebsocketHandler)\n\n\nSynonyms:\nmist/handler.HandlerResponse\nmist/handler HandlerResponse","url":"mist/handler.html#HandlerResponse"},{"doc":"mist/handler","title":"State","content":"pub type State {\n  State(\n    idle_timer: Option(process.Timer),\n    upgraded_handler: Option(websocket.WebsocketHandler),\n  )\n}\n\nState(\n  idle_timer: Option(process.Timer),\n  upgraded_handler: Option(websocket.WebsocketHandler),\n)\n\n\nSynonyms:\nmist/handler.State\nmist/handler State","url":"mist/handler.html#State"},{"doc":"mist/handler","title":"new_state","content":"pub fn new_state() -&gt; State\n\nSynonyms:\nmist/handler.new_state\nmist/handler new_state","url":"mist/handler.html#new_state"},{"doc":"mist/handler","title":"with","content":"pub fn with(handler: fn(Request(BitString)) -&gt;\n    Response(BitBuilder), max_body_limit: Int) -&gt; fn(\n  HandlerMessage,\n  LoopState(State),\n) -&gt; Next(LoopState(State))\n Creates a standard HTTP handler service to pass to `mist.serve`\nSynonyms:\nmist/handler.with\nmist/handler with","url":"mist/handler.html#with"},{"doc":"mist/handler","title":"with_func","content":"pub fn with_func(handler: fn(Request(Body)) -&gt; HandlerResponse) -&gt; fn(\n  HandlerMessage,\n  LoopState(State),\n) -&gt; Next(LoopState(State))\n This is a more flexible handler. It will allow you to upgrade a connection\n to a websocket connection, or deal with a regular HTTP req-&gt;resp workflow.\nSynonyms:\nmist/handler.with_func\nmist/handler with_func","url":"mist/handler.html#with_func"},{"doc":"mist/handler","title":"mist/handler","content":"","url":"mist/handler.html"},{"doc":"mist","title":"run_service","content":"pub fn run_service(port: Int, handler: fn(Request(BitString)) -&gt;\n    Response(BitBuilder), max_body_limit max_body_limit: Int) -&gt; Result(\n  Nil,\n  StartError,\n)\n Runs an HTTP Request-&gt;Response server at the given port, with your defined\n handler. This will automatically read the full body contents up to the\n specified `max_body_limit` in bytes. If you&#39;d prefer to have finer-grain\n control over this behavior, consider using `mist.serve`.\nSynonyms:\nmist.run_service\nmist run_service","url":"mist.html#run_service"},{"doc":"mist","title":"run_service_ssl","content":"pub fn run_service_ssl(port port: Int, certfile certfile: String, keyfile keyfile: String, handler handler: fn(\n    Request(BitString),\n  ) -&gt; Response(BitBuilder), max_body_limit max_body_limit: Int) -&gt; Result(\n  Nil,\n  StartError,\n)\n Similar setup and behavior to `run_service`, but instead takes in the SSL\n certificate/key and serves over HTTPS.\nSynonyms:\nmist.run_service_ssl\nmist run_service_ssl","url":"mist.html#run_service_ssl"},{"doc":"mist","title":"serve","content":"pub fn serve(port port: Int, handler handler: fn(\n    HandlerMessage,\n    LoopState(State),\n  ) -&gt; Next(LoopState(State))) -&gt; Result(Nil, StartError)\n Slightly more flexible alternative to `run_service`. This allows hooking\n into the `mist/http.{handler_func}` method. Note that the request body\n will not be automatically read. You will need to call `http.read_body`.\nSynonyms:\nmist.serve\nmist serve","url":"mist.html#serve"},{"doc":"mist","title":"serve_ssl","content":"pub fn serve_ssl(port port: Int, certfile certfile: String, keyfile keyfile: String, handler handler: fn(\n    HandlerMessage,\n    LoopState(State),\n  ) -&gt; Next(LoopState(State))) -&gt; Result(Nil, StartError)\n Similar to the `run_service` method, `serve` also has a similar SSL method.\nSynonyms:\nmist.serve_ssl\nmist serve_ssl","url":"mist.html#serve_ssl"},{"doc":"mist","title":"mist","content":"","url":"mist.html"}]);